module RubyYacht
  # This class provides configuration for DNS servers for your apps.
  #
  # This is optional. If you don't provide any DNS server configuration, we will
  # use docker's default DNS configuration.
  #
  # You can configure this with RubyYacht::DnsServer::DSL
  class DnsServer
    # The servers that we use for DNS. Each entry is a String.
    attr_accessor :servers
    
    # The domains that we use for default DNS lookup. Each entry is a String.
    attr_accessor :search_domains
    
    # This class provides a DSL for configuring DNS server options.
    #
    # You can access this by calling `dns_server` within RubyYacht::Project::DSL.
    # It will create a RubyYacht::DnsServer.
    class DSL
      include RubyYacht::DSL::Base
      extend RubyYacht::DSL::Base::ClassMethods
      
      ##
      # :method: server
      # You can call `server '1.2.3.4'` to add `1.2.3.4` to the project's list of
      # DNS servers.
      add_list :server
      
      ##
      # :method: search_domain
      # You can call `search_domain 'apps.test.com'` to add `apps.test.com` to
      # the list of domains that we automatically search for in the DNS.
      add_list :search_domain
      
      creates_object DnsServer
    end
  end
end