module RubyYacht::Plugins
  # This module provides the plugin for managing nginx web servers.
  module Nginx
    # This method loads the configuration for the nginx plugin.
    def self.load
      RubyYacht.configure do
        server_type :nginx do
          container_type :web
          baseline_image 'nginx'
        end
      end

      RubyYacht.configure do
        add_hooks container_type: :web, web_server_type: :nginx, script_folder: File.join(File.dirname(__FILE__), 'nginx', 'scripts') do
          during(:install_libraries) { command 'apt-get install -y ruby' }
          during(:install_libraries) { copy_file 'index.html.erb' }
          during(:install_libraries) { copy_file 'index_config.erb' }
          during(:install_libraries) { copy_file 'app_config.erb' }

          during(:add_project_landing) { run_script :ruby, 'add_project.rb' }
          during(:add_app_config) { run_script :ruby, 'add_app.rb' }

          during(:cleanup) do
            command 'apt-get remove -y ruby'
            command 'apt-get autoremove -y'
          end
        end
      end
    end
  end
end

RubyYacht::Plugins::Nginx.load