module RubyYacht::Runner
  # This command provides help information about other commands.
  class Help < Command
    # The name of the command.
    def self.command; 'help'; end

    # The short description of the command.
    def self.description
      "Get information on available commands"
    end

    # The command that we are getting help in.
    attr_accessor :command

    # This method gets the command-line options for the command.
    def option_parser
      OptionParser.new do |options|
        options.banner = "Usage: #{Command.short_script_name} help [command]\n\n#{self.class.description}"
      end
    end

    # This method extracts arguments from the command line.
    #
    # ### Parameters
    #
    # * **arguments: Array**    The command line arguments.
    def parse_positional_arguments(arguments)
      self.command = arguments.shift
    end 

    # This method runs the logic for the command.
    def run
      if self.command
        RubyYacht::Runner.commands.each do |command|
          if command.command == self.command
            log command.new.option_parser.to_s
            return true
          end
        end

        log "Command not available: #{self.command}"
        log "Run #{Command.short_script_name} help for more options"
        return false
      end

      log "Available commands: \n\n"
      RubyYacht::Runner.commands.each do |command|
        log "#{command.command}: #{command.description}"
      end

      log "\nRun #{Command.short_script_name} help [command] for more information on a command"
      true
    end
  end
end